# frozen_string_literal: true

module VersionCheckHelper
  def version_status_badge
    return unless Rails.env.production?

    # maybe we'll re-enable once Heptapod catches up on GitLab, but
    # that would require providing meaningful links to downloads/procedures
    # that was Gitlab::CurrentSettings.version_check_enabled
    return unless false
    return if User.single_user&.requires_usage_stats_consent?

    image_tag VersionCheck.url, class: 'js-version-status-badge'
  end

  def link_to_version
    if Gitlab.pre_release?
      # we don't have working links from Hg revision node id in Heptapod yet.
      commit_link = link_to(Gitlab.revision, Gitlab::HEPTAPOD_SELF_URL + '/heptapod/' + source_code_project)
      [Gitlab::HEPTAPOD_VERSION,
       content_tag(:small, '(' + Gitlab::VERSION + ')'),
       content_tag(:small, commit_link)].join(' ').html_safe
    else
      link_to Gitlab::HEPTAPOD_VERSION, Gitlab::HEPTAPOD_SELF_URL + namespace_project_tag_path('heptapod', source_code_project, "heptapod-#{Gitlab::HEPTAPOD_VERSION}")
    end
  end

  def source_code_project
    'heptapod'
  end
end

VersionCheckHelper.prepend_if_ee('EE::VersionCheckHelper')
