# frozen_string_literal: true

module Gitlab
  module Mercurial
    NULL_NODE = ('00' * 20).freeze

    BookmarksUnsupportedError = Class.new(StandardError)

    class << self
      # Suitable value for HGRCPATH so that structural and default settings
      # are loaded and an application wide can override them.
      def hgrc_path
        Gitlab.config.mercurial.hgrc.join(":")
      end

      def parse_gitlab_branch_for_hg(gitlab_branch)
        if gitlab_branch.start_with?('branch/')
          [gitlab_branch[7..], nil]
        elsif gitlab_branch.start_with?('topic/')
          branch, _slash, topic = gitlab_branch[6..].rpartition('/')
          [branch, topic]
        else
          raise BookmarksUnsupportedError, gitlab_branch
        end
      end

      def parse_hg_archival(lines)
        arch = {}
        lines.each do |l|
          key, value = l.split(":", 2)
          arch[key.to_sym] = value.strip
        end
        arch
      end

      # dir_path: where `.hg_archival.txt` is expected to be
      #           the best is to provide a Pathname instance, but strings are
      #           accepted
      # returns nil if archival file does not exist, otherwise a Hash with
      #         symbol keys.
      def read_hg_archival(dir_path)
        path = Pathname(dir_path).join(".hg_archival.txt")
        return unless path.exist?

        parse_hg_archival(path.readlines)
      end
    end
  end
end
