namespace :gitlab do
  namespace :git do
    desc 'GitLab | Git | Check all repos integrity'
    task fsck: :gitlab_environment do
      failures = []
      Project.find_each(batch_size: 100) do |project|
        begin
          project.repository.fsck

        rescue => e
          failures << "#{project.full_path} on #{project.repository_storage}: #{e}"
        end

        puts "Performed integrity check for #{project.repository.full_path}"
      end

      if failures.empty?
        puts "Done".color(:green)
      else
        puts "The following repositories reported errors:".color(:red)
        failures.each { |f| puts "- #{f}" }
      end
    end
    task force_housekeeping: :gitlab_environment do
      project_id = ENV['PROJECT_ID']
      if project_id.nil?
        puts "Please specify PROJECT_ID".color(:orange)
        next
      end
      puts "Performing housekeeping (GitGarbageCollectWorker) for Project #{project_id}".color(:green)
      begin
        GitGarbageCollectWorker.new().perform(
          project_id,
          task = :full_repack,
          lease_key = "project_housekeeping:#{project_id}"
        )
        puts "Done.".color(:green)
      rescue StandardError => err
        puts ("Error for Project id=#{project_id} #{err.class.name}: #{err.message}\n" + err.backtrace.join("\n")).color(:red)
      end
    end
  end
end
