#!/bin/sh

set -e

if echo "$CI_COMMIT_TAG" | grep '^heptapod-'; then
    TARBALL=$(echo -n $CI_COMMIT_TAG | sed s/heptapod/heptapod-rails/g)
    # pulling on the current branch and the two main heptapod ones
    # so that `hg archive` should see the tag (very unlikely the tagging
    # changeset would be elsewhere, not worth pulling the whole repo)
    # using `hg log` instead of `hg branch` to avoid newline for safety
    hg pull -r heptapod -r heptapod-stable -r `hg log -r. -T "{branch}"` || /bin/true
else
    TARBALL=heptapod-rails-$(hg log -r. -T "{node}")
fi

# it's nicer for console output to add the extension right away
TARBALL=${TARBALL}.tar.gz

TARBALL_PATH=/tmp/${TARBALL}

echo "Generating ${TARBALL}"
hg archive -t tgz ${TARBALL_PATH}
sha256sum ${TARBALL_PATH} > ${TARBALL_PATH}.sha256sum

if [ -n "$HEPTAPOD_TARBALL_UPLOAD_KEY" ]; then
    HEPTAPOD_DOWNLOAD_SITE=download.heptapod.net
    echo "Pushing ${TARBALL} to ${HEPTAPOD_DOWNLOAD_SITE} via SFTP"

    # TODO better to ship a known_hosts file
    #
    # StricHostKeyChecking=accept-new not available in base Docker image
    #
    # ssh_config(5) on Debian 9 (OpenSSH 7.4):
    #    If this flag is set to no, ssh will automatically add new host keys
    #    to the user known hosts files.
    #
    # ssh_config(5) on Debian 10 (OpenSSH 7.9):
    #    If this flag is set to “accept-new” then ssh will automatically add
    #    new host keys to the user known hosts files, but will not permit
    #    connections to hosts with changed host keys. If this flag is set
    #    to “no” or “off”, ssh will automatically add new host keys
    #    to the user known hosts files and allow connections to hosts
    #    with changed hostkeys to proceed, subject to some restrictions.
    SSH_FLAGS="-o IdentitiesOnly=yes -o StrictHostKeyChecking=no"

    if [ -n "$HEPTAPOD_UPLOAD_SSH_PORT" ]; then
        SSH_FLAGS="$SSH_FLAGS -P $HEPTAPOD_UPLOAD_SSH_PORT"
    fi

    # TODO it would be nice of the runner to set restrictive permissions
    # this right at file creation time (perhaps based on a declarative option),
    # especially since there's no job filtering except based on environments
    chmod 600 ${HEPTAPOD_TARBALL_UPLOAD_KEY}
    echo "put ${TARBALL_PATH}*" | sftp -b- \
         ${SSH_FLAGS} \
         -i ${HEPTAPOD_TARBALL_UPLOAD_KEY} \
         ${HEPTAPOD_UPLOAD_SSH_USER}@${HEPTAPOD_DOWNLOAD_SITE}:${HEPTAPOD_UPLOAD_SSH_USER}/public/src
fi
